docopt.sh
=========

A [docopt](http://docopt.org/) argument parser for bash 3.2, 4+, and 5+ with no
external dependencies.

The full documentation is available on [GitHub](https://github.com/andsens/docopt.sh#docoptsh).
